@@ -22,9 +22,9 @@
 # contact with opensource@tid.es
 
 
-from utils.rest_client_utils import RestClient, API_ROOT_URL_ARG_NAME, response_body_to_dict, \
+from sdcclient.utils.rest_client_utils import RestClient, API_ROOT_URL_ARG_NAME, response_body_to_dict, \
     HEADER_CONTENT_TYPE, HEADER_REPRESENTATION_XML
-from utils.logger_utils import get_logger
+from sdcclient.utils.logger_utils import get_logger
 
 logger = get_logger(__name__)
 
